@@ -72,7 +72,17 @@ INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5765', 'Rparation et entretien', 'A', 'E', 'AP_amount', '8964');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5800', 'Taxes d''affaires, droits d''adhsion et permis', 'A', 'E', 'AP_amount', '8760');
 --
-insert into tax (chart_id,rate) values ((select id from chart where accno = '2310'),0.07);
-insert into tax (chart_id,rate) values ((select id from chart where accno = '2320'),0.08025);
+insert into tax (chart_id,rate) values ((select id from chart where accno = '2310'),0.05);
+insert into tax (chart_id,rate) values ((select id from chart where accno = '2320'),0.07875);
 --
-update defaults set inventory_accno_id = (select id from chart where accno = '1520'), income_accno_id = (select id from chart where accno = '4020'), expense_accno_id = (select id from chart where accno = '5010'), fxgain_accno_id = (select id from chart where accno = '4450'), fxloss_accno_id = (select id from chart where accno = '4450'), curr = 'CAD:USD:EUR', weightunit = 'kg';
+INSERT INTO defaults (fldname, fldvalue) VALUES ('inventory_accno_id', (SELECT id FROM chart WHERE accno = '1520'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('income_accno_id', (SELECT id FROM chart WHERE accno = '4020'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('expense_accno_id', (SELECT id FROM chart WHERE accno = '5010'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('fxgain_accno_id', (SELECT id FROM chart WHERE accno = '4450'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('fxloss_accno_id', (SELECT id FROM chart WHERE accno = '4450'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('weightunit', 'kg');
+INSERT INTO defaults (fldname, fldvalue) VALUES ('precision', '2');
+--
+INSERT INTO curr (rn, curr, precision) VALUES (1,'CAD',2);
+INSERT INTO curr (rn, curr, precision) VALUES (2,'USD',2);
+INSERT INTO curr (rn, curr, precision) VALUES (3,'EUR',2);
